@@ -18,6 +18,10 @@ except ImportError:
     from django.contrib.staticfiles.handlers import StaticFilesHandler
 
 from webtest import TestApp
+try:
+    from webtest.utils import NoDefault
+except ImportError:
+    NoDefault = ''
 
 from django_webtest.response import DjangoWebtestResponse
 from django_webtest.compat import to_string, to_wsgi_safe_string
@@ -96,10 +100,10 @@ class DjangoTestApp(TestApp):
 
     def get(self, url, params=None, headers=None, extra_environ=None,
             status=None, expect_errors=False, user=None, auto_follow=False,
-            content_type=None):
+            content_type=None, **kwargs):
         extra_environ = self._update_environ(extra_environ, user)
         response = super(DjangoTestApp, self).get(
-                  url, params, headers, extra_environ, status, expect_errors)
+                url, params, headers, extra_environ, status, expect_errors, **kwargs)
 
         is_redirect = lambda r: r.status_int >= 300 and r.status_int < 400
         while auto_follow and is_redirect(response):
@@ -109,15 +113,15 @@ class DjangoTestApp(TestApp):
 
     def post(self, url, params='', headers=None, extra_environ=None,
              status=None, upload_files=None, expect_errors=False,
-             content_type=None, user=None):
+             content_type=None, user=None, **kwargs):
         extra_environ = self._update_environ(extra_environ, user)
         return super(DjangoTestApp, self).post(
                    url, params, headers, extra_environ, status,
-                   upload_files, expect_errors, content_type)
+                   upload_files, expect_errors, content_type, **kwargs)
 
     def put(self, url, params='', headers=None, extra_environ=None,
              status=None, upload_files=None, expect_errors=False,
-             content_type=None, user=None):
+             content_type=None, user=None, **kwargs):
         extra_environ = self._update_environ(extra_environ, user)
         return super(DjangoTestApp, self).put(
                    url, params, headers, extra_environ, status,
@@ -125,27 +129,26 @@ class DjangoTestApp(TestApp):
 
     def patch(self, url, params='', headers=None, extra_environ=None,
              status=None, upload_files=None, expect_errors=False,
-             content_type=None, user=None):
+             content_type=None, user=None, **kwargs):
         extra_environ = self._update_environ(extra_environ, user)
         return super(DjangoTestApp, self).patch(
                    url, params, headers, extra_environ, status,
-                   upload_files, expect_errors, content_type)
+                   upload_files, expect_errors, content_type, **kwargs)
 
     def options(self, url, params='', headers=None, extra_environ=None,
              status=None, upload_files=None, expect_errors=False,
-             content_type=None, user=None):
+             content_type=None, user=None, **kwargs):
         extra_environ = self._update_environ(extra_environ, user)
         return super(DjangoTestApp, self).options(
-                   url, params, headers, extra_environ, status,
-                   upload_files, expect_errors, content_type)
+                   url, params, headers, extra_environ, status, **kwargs)
 
-    def delete(self, url, params='', headers=None, extra_environ=None,
+    def delete(self, url, params=NoDefault, headers=None, extra_environ=None,
              status=None, expect_errors=False,
-             content_type=None, user=None):
+             content_type=None, user=None, **kwargs):
         extra_environ = self._update_environ(extra_environ, user)
         return super(DjangoTestApp, self).delete(
                    url, params, headers, extra_environ, status,
-                   expect_errors, content_type)
+                   expect_errors, content_type, **kwargs)
 
     @property
     def session(self):
@@ -240,7 +243,7 @@ class WebTest(WebTestMixin, TestCase):
     pass
 
 
-class TransactionWebTest(WebTestMixin, TestCase):
+class TransactionWebTest(WebTestMixin, TransactionTestCase):
     pass
 
 
